==> munit-maven-plugins-common-2.3.13-sources.jar: org/mule/munit/plugin/maven/runner/JVMStarter.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.plugin.maven.runner;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.Map;

import org.apache.maven.plugin.logging.Log;
import org.apache.maven.shared.utils.cli.CommandLineException;
import org.apache.maven.shared.utils.cli.CommandLineUtils;
import org.apache.maven.shared.utils.cli.Commandline;
import org.apache.maven.shared.utils.cli.StreamConsumer;

/**
 * <p>
 * The goal of this class is to start a new JVM based on the given parameters
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class JVMStarter {

  private Log log;
  protected Commandline commandline = new Commandline();


  public JVMStarter(Log log) throws IOException {
    this.log = log;
  }

  public JVMStarter withJVM(String jvm) {
    commandline.setExecutable(jvm);
    return this;
  }

  public JVMStarter withJar(File jarFile) {
    commandline.createArg().setValue("-jar");
    commandline.createArg().setFile(jarFile);
    return this;
  }

  public JVMStarter withWorkingDirectory(File workingDirectory) {
    commandline.setWorkingDirectory(workingDirectory);
    return this;
  }

  public JVMStarter withArgLines(List<String> argLines) {
    for (String argLine : argLines) {
      commandline.createArg(true).setValue(argLine);
    }
    return this;
  }

  public JVMStarter withArgLines(Map<String, File> argLines) {
    for (Map.Entry<String, File> argLine : argLines.entrySet()) {
      commandline.createArg().setValue(argLine.getKey());
      commandline.createArg().setFile(argLine.getValue());
    }
    return this;
  }

  public JVMStarter withSystemProperties(Map<String, String> systemProperties) {
    for (Map.Entry<String, String> prop : systemProperties.entrySet()) {
      commandline.createArg(true).setValue("-D" + prop.getKey() + "=" + prop.getValue());
    }
    return this;
  }

  public JVMStarter addEnvironmentVariables(Map<String, String> environmentVariables) {
    for (Map.Entry<String, String> envVar : environmentVariables.entrySet()) {
      commandline.addEnvironment(envVar.getKey(), envVar.getValue());
    }
    return this;
  }

  public int execute(StreamConsumer outStreamConsumer, StreamConsumer errStreamConsumer) throws CommandLineException {
    log.debug("Executing command line: " + commandline);
    return CommandLineUtils.executeCommandLine(commandline, outStreamConsumer, errStreamConsumer);
  }

}

==> munit-maven-plugins-common-3.0.0-sources.jar: org/mule/munit/plugin/maven/runner/JVMStarter.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.plugin.maven.runner;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;
import org.apache.maven.plugin.logging.Log;
import org.apache.maven.shared.utils.cli.*;

/**
 * <p>
 * The goal of this class is to start a new JVM based on the given parameters
 * </p>
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class JVMStarter {

  private Log log;
  protected Commandline commandline = new Commandline();
  protected Commandline commandlineVersion = new Commandline();


  public JVMStarter(Log log) throws IOException {
    this.log = log;
  }

  public JVMStarter withJVM(String jvm) {
    commandline.setExecutable(jvm);
    commandlineVersion.setExecutable(jvm);
    return this;
  }

  public JVMStarter withJar(File jarFile) {
    commandline.createArg().setValue("-jar");
    commandline.createArg().setFile(jarFile);
    return this;
  }

  public JVMStarter withWorkingDirectory(File workingDirectory) {
    commandline.setWorkingDirectory(workingDirectory);
    commandlineVersion.setWorkingDirectory(workingDirectory);
    return this;
  }

  public JVMStarter withArgLines(List<String> argLines) {
    for (String argLine : argLines) {
      commandline.createArg(true).setValue(argLine);
    }
    return this;
  }

  public JVMStarter withArgLines(Map<String, File> argLines) {
    for (Map.Entry<String, File> argLine : argLines.entrySet()) {
      commandline.createArg().setValue(argLine.getKey());
      commandline.createArg().setFile(argLine.getValue());
    }
    return this;
  }

  public JVMStarter withSystemProperties(Map<String, String> systemProperties) {
    for (Map.Entry<String, String> prop : systemProperties.entrySet()) {
      commandline.createArg(true).setValue("-D" + prop.getKey() + "=" + prop.getValue());
    }
    return this;
  }

  public JVMStarter addEnvironmentVariables(Map<String, String> environmentVariables) {
    for (Map.Entry<String, String> envVar : environmentVariables.entrySet()) {
      commandline.addEnvironment(envVar.getKey(), envVar.getValue());
    }
    return this;
  }

  public int execute(StreamConsumer outStreamConsumer, StreamConsumer errStreamConsumer) throws CommandLineException {
    log.debug("Executing command line: " + commandline);
    return CommandLineUtils.executeCommandLine(commandline, outStreamConsumer, errStreamConsumer);
  }

  public String getVersion() {
    outputStreamString outStream = new outputStreamString();
    outputStreamString outStreamError = new outputStreamString();
    try {
      commandlineVersion.addArguments("-version");
      CommandLineUtils.executeCommandLine(commandlineVersion, outStream, outStreamError);
    } catch (CommandLineException e) {
      throw new RuntimeException(e);
    }
    String output = outStream.getOutput().equals("") ? outStreamError.getOutput() : outStream.getOutput();
    return StringUtils.substringBetween(output, "\"", "\"");
  }

}


class outputStreamString implements StreamConsumer {

  private String output = "";

  @Override
  public void consumeLine(String line) throws IOException {
    output = output + line;
  }

  public String getOutput() {
    return output;
  }
}
